Documentation
¶
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DiscoverFilesInDirectory ¶
DiscoverFilesInDirectory automates discovery of files in directory and returns []string
func FindFileInDirectory ¶
FindFileInDirectory takes a directory and a filename and returns the relative path of that file if exists
func FindFilesByTypeInDirectory ¶
FindFilesByTypeInDirectory returns the path of all files in the directory of a specific extension
Types ¶
type Everglade ¶ added in v1.3.1
func (*Everglade) Encrypt ¶ added in v1.3.1
Example ¶
// File to encrypt in this test
fn := "everglade.go"
// e.blind houses your keys and can be exported to/from if needed.
e, err := New(1)
if err != nil {
panic(err)
}
// Add the files to encrypt to this list
err = e.Add(fn)
if err != nil {
panic(err)
}
// Encrypt the files that were added with AES-CBC-128.
// This includes a random nonce and IV.
err = e.Encrypt()
if err != nil {
panic(err)
}
Click to show internal directories.
Click to hide internal directories.